@@ -77,6 +77,12 @@ QHash<QString, QDateTime> DateTimeRunner::datetime(const QStringRef &tz)
             continue;
         }
 
+        const QString displayName = timeZone.displayName(QDateTime::currentDateTime(), QTimeZone::LongName);
+        if (displayName.contains(tz, Qt::CaseInsensitive)) {
+            ret[displayName] = QDateTime::currentDateTimeUtc().toTimeZone(timeZone);
+            continue;
+        }
+
         const QString country = QLocale::countryToString(timeZone.country());
         if (country.contains(tz, Qt::CaseInsensitive)) {
             ret[country] = QDateTime::currentDateTimeUtc().toTimeZone(timeZone);
@@ -107,6 +113,6 @@ void DateTimeRunner::addMatch(const QString &text, const QString &clipboardText,
     context.addMatch(match);
 }
 
-K_EXPORT_PLASMA_RUNNER_WITH_JSON(DateTimeRunner, "plasma-runner-datetime.json")
+K_PLUGIN_CLASS_WITH_JSON(DateTimeRunner, "plasma-runner-datetime.json")
 
 #include "datetimerunner.moc"
